#
# spec file for package spacefm
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with restricted
Name:           spacefm
Version:        1.0.6
Release:        2.1
Summary:        Multi-panel tabbed file and desktop manager
License:        GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            http://ignorantguru.github.io/spacefm
Source:         https://github.com/IgnorantGuru/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE spacefm-fix-implicit-decl.patch -- Fix implicit declaration of "major" and "minor" macros.
Patch0:         spacefm-fix-implicit-decl.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.0.0
BuildRequires:  pkgconfig(libudev) >= 143
Requires:       desktop-file-utils
Requires:       shared-mime-info
Recommends:     %{name}-lang
# Mount without root requirement.
Recommends:     udisks2
# Plugin download.
Recommends:     wget
# Execution of SpaceFM and applications from root.
Recommends:     xdg-utils
%if %{?suse_version} >= 1500 || %{with restricted}
BuildRequires:  pkgconfig(libffmpegthumbnailer)
%endif

%description
SpaceFM is a multi-panel tabbed file and desktop manager for GNU/Linux
with built-in VFS, udev-based device manager, customisable menu system
and bash integration. SpaceFM is popular among novice and power users
alike for its stability, speed, convenience and flexibility.

%lang_package

%prep
%setup -q
%patch0 -p1
echo 'tmp_dir=%{_tmppath}' > %{name}.conf

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
  --with-preferable-sudo=%{_bindir}/xdg-su \
%if %{?suse_version} < 1500 && %{without restricted}
  --disable-video-thumbnails               \
%endif
  --htmldir=%{_docdir}/%{name}
make %{?_smp_mflags} V=1

%install
%make_install

%suse_update_desktop_file -G 'Search for Files' %{name}-find GTK System Utility FileManager
%fdupes %{buildroot}%{_datadir}/
%find_lang %{name}

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post
%icon_theme_cache_post Faenza
%mime_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%icon_theme_cache_postun Faenza
%mime_database_postun
%endif

%files
%if 0%{?suse_version} >= 1500
%license COPYING COPYING-LGPL
%else
%doc COPYING COPYING-LGPL
%endif
%doc AUTHORS ChangeLog README
%{_docdir}/%{name}/
%dir %{_sysconfdir}/%{name}/
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%{_bindir}/%{name}*
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*.png
%dir %{_datadir}/icons/Faenza/
%dir %{_datadir}/icons/Faenza/apps/
%dir %{_datadir}/icons/Faenza/apps/*/
%{_datadir}/icons/Faenza/apps/*/%{name}*.png
%{_datadir}/mime/packages/%{name}-mime.xml

%files lang -f %{name}.lang

%changelog
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Add spacefm-fix-implicit-decl.patch: Fix implicit declaration of
  "major" and "minor" macros.
* Sat Apr  7 2018 sor.alexei@meowr.ru
- Update to version 1.0.6:
  * Rename dlg canonicalise Copy Target/Link Target target when
    possible.
  * [GTK+2] Fix black background directory load regression.
  * [GTK+3.20] Fix theme parse warnings re close btn css.
  * [GTK+2] Iconview no longer responds to theme change.
  * Fix a compilation failure due to glibc include changes.
  * User manual minor updates.
  * Default Devices|Root|Check fsck command add -r for repair.
  * File|Open URL add example mtp://.
  * Add sftp to ssh protocol handler default whitelist (allows
    sftp://).
  * settings.c: (style) Clarify expression with parentheses.
  * Fix a segfault in ptk/ptk-dir-tree.c.
  * Fix newly imported file handlers appear in Plugins menu.
  * Dbl-click to enter a directory selects a file.
  * Fix a segfault when dragging a directory or a file to the
    desktop.
  * [desktop] Fix GTK+3 icon movement, reliably get mouse state.
  * Load icon using icon name in theme if removed suffix fails.
  * [desktop] Paint root window when there is no wallpaper.
  * Fix source file permissions.
  * [GTK+3.22] Fix segfault dragging files to directory tree.
  * Fix drag & drop segfaults.
  * Fix segfault on drag to reorder bookmarks.
  * Fix davfs is not mounted.
  * Fix fuse default protocol handler not added due to false
    positive test.
  * Fix bookmark pane and toolbar two-finger right-click.
  * Fix file list new bookmark with topmost bookmark selected.
  * Fix mktemp in mtp handler being not busybox compatible.
  * Update translations.
- Build with ffmpegthumbnailer on openSUSE Leap 15.0 and later.
- Remove the gtk2 bcond.
* Sun Mar 12 2017 sor.alexei@meowr.ru
- Explicitly package %%{_docdir}/%%{name}/.
* Thu Jan 21 2016 sor.alexei@meowr.ru
- Update to 1.0.5:
  * Recreate too small cached thumbnails.
  * Read $XDG_TEMPLATES_DIR via glib for user-dirs.dirs support.
  * Devices|Settings|Auto-Mount|Mount Dirs accept XDG vars, mkdir.
  * Fix Paste in directory tree pastes to a wrong directory.
  * Menu key in directory tree changes directory and acts on the
    correct directory.
  * [desktop] Show video thumbnails on desktop.
  * Preferences add 384x384 icon size option.
  * Obey StartupNotify when opening with an desktop application.
  * configure.ac set G_LOG_DOMAIN.
  * Fix main.c debug_gdk_threads_leave.
  * Change detection, blacklist detect new files.
  * Get mime type of only reg and link files, not char dev.
  * Fix segfault in ptk_bookmark_view_reload_list to vfs_load_icon.
  * Prevent filesystem find loop hang in new file/directory dialog.
  * Fix crash on GTK+ icon theme reload; fix liststore memory leaks.
  * udevil iso unmount device handler new whitelist/blacklist.
  * Fix broken key shortcuts in Open|In Panel menu.
  * Add lxqt-sudo and lxsu to list of su frontends.
  * Add support for qterminal in list of terminals.
  * Make Paste As Target paste canonicalised final target when
    possible.
* Mon Oct 19 2015 sor.alexei@meowr.ru
- Update to 1.0.4:
  * ifdef malloc_trim for non-glibc libraries.
  * Fix HAL build.
  * Fix older Gtk2 build.
  * Menu and Shift+F10 show side pane menus.
  * Design Menu shown with Menu key in addition to F2.
  * Directory tree allow keyboard navigation, keep focus.
  * Directory tree double-click expands/collapses row.
  * Directory tree context menu|New|Tab Here opens a selected
    directory.
  * Correct location for Gtk3 bookmarks import; use basename.
  * Don't continuously refresh copying video thumbnails.
  * New in /etc/spacefm/spacefm.conf: terminal_su and graphical_su.
  * Build system now installs /etc/spacefm/spacefm.conf.
  * New configure option --sysconfdir=/etc to set location of /etc.
  * Add new event for tab change dir evt_tab_chdir; update manual.
  * Replace show-menu socket method with activate for all item types.
  * [Dialog] Add non-visible element --click to run cmd on click.
  * [Dialog] Fix some internal var names always set to %%v.
  * Increase Max icon/thumbnail size from 256x256 to 512x512.
  * [Gtk3] Fix wrong colours with dark variants of Gtk themes.
* Fri Aug 28 2015 sor.alexei@meowr.ru
- Update to 1.0.3:
  * Add Devices|Settings|Auto-Mount|Mount Dirs option.
  * Proto hand keep %%a for lxterminal, urxvtc, konsole,
    gnome-terminal.
  * Convert non-latin keycodes to latin.
  * Add ltg locale, update it, lt, and pt_BR.
  * configure.ac define G_DISABLE_ASSERT to disable g_assert.
  * Rename gphoto handler as ptp; whitelist ptp.
  * [Gtk3] add icon chooser dialog.
  * Double-click in icon chooser clicks OK.
  * [Gtk 3.14] Prevent empty rubberband selection Gtk3.14 bug avoid.
  * Provide export and import of handler plugin files; update manual.
  * Create %%O archive in user-selected destination.
  * Fix LilyTerm not working correctly eg unzipping file.
  * Update spacefm.desktop for protocol handling.
- Remove -mmmx CFLAGS hack and do not ExcludeArch PowerPC anymore.
* Mon Aug 10 2015 normand@linux.vnet.ibm.com
-  explicit ExcludeArch for ppc ppc64 ppc64le
  (do not build mmx)
* Thu Jun  4 2015 sor.alexei@meowr.ru
- Update to 1.0.2:
  * Toolbar redesign with design mode right-click ability.
  * Add built-in toolbar items: Show Hidden, Show Thumbnails,
    Large Icons.
  * Fix Compact view sometimes fails to scroll to selected file.
  * malloc_trim calls to flush out the free heap back to the OS
    when needed.
  * Fix forgets compress handler after extract to.
  * No re-import bookmarks when up-down-upgrade from < 1.0.1.
  * Missing pixbuf unref in main_task_view_update_task.
  * Add keyboard shortcut for handler list in handler dialogs.
  * Fix ftp handler ignores custom port in URL.
  * Add Run As Task option to file handlers.
  * Allow escape of underscore in item names.
  * Fix Item Prop context opposite of Disable is Show instead of
    Enable.
  * Get mime type icon from .local XML file before guess.
  * Fix right-click on Bookmarks activates bookmark after menu.
  * Fix right-click detailed view clears multiple-file selection.
  * Add panel View context menu to main View menu.
  * Add View|Style|Thumbnails (global).
  * Add show_thumbnails socket property.
  * Fix missing paths on command line hangs.
  * Fix hang on access error on startup.
  * Fix icon/compact view left-click doesn't unselect other files.
  * Write/read new mimeapps.list Default Applications.
  * Archive handlers take precedence over file handlers.
  * Scale menu item icons loaded from file.
  * Force rebuild of folder_view for font change in exo_icon_view.
  * Always reap async child with or without exec_keep_tmp.
  * Default scroll desktop fix openbox.
  * Always update status bar Reading msg.
  * Item prop dlg text view scroll add shadow.
  * Fix linefeeds in .desktop item names.
* Tue May  5 2015 sor.alexei@meowr.ru
- Update to 1.0.1:
  * Extended bookmarks system.
  * Added users manual Bookmarks section.
  * Fix --enable-hal build errors.
  * Fix segfault in vfs_thumbnail_loader_free on abort thumbnail
    loading.
  * _vfs_thumbnail_load unref after
    gdk_pixbuf_apply_embedded_orientation.
  * MIME Menu prompt before creating files.
  * Open menu archive functions move to top if default.
  * Rewrite ptk_file_browser_refresh; reselect cursor after
    refresh.
  * Status bar shows Reading msg while dir loading.
  * New protocol handler http/webdav to top of list.
  * Bookmarks|New Bookmark default key shortcut Ctrl+D.
- Switch to Gtk3.
* Wed Apr 15 2015 sor.alexei@meowr.ru
- Initial package.
